/*
 * @Description: 点检项目相关
 * @Author: Ben Lin
 * @version:
 * @Date: 2024-06-19 20:34:27
 * @LastEditors: Ben Lin
 * @LastEditTime: 2024-08-06 19:46:17
 */

import { ActionItem, BasicColumn } from '/@/components/Table';
import { useI18n } from '/@/hooks/web/useI18n';

const { t } = useI18n();
const isQuantitative = (type: number) => type === 0;
const isQualitative = (type: number) => type === 1;
function _default() {
  const ActionColumn: BasicColumn = {
    width: 80,
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    fixed: undefined,
  };

  /**
   * @description: 一些自定义方法
   * @return {*}
   */
  const methods = {
    /**
     * @description: 获取新增按钮的行为
     * @return {*}
     */
    CreateAction: (type: string) => {
      return {
        action: 'drawer', //drawer(打开左侧抽屉框) | go(跳转到新的页面)
      };
    },
    /**
     * @description: 操作字段自定义按钮
     * @return {*}
     */
    ActionItem: (params: Recordable<any>, data, ...args): ActionItem[] => {
      return data;
    },
    /**
     * @description: 选择过程变量弹出选择框成功返回赋值方法
     * @param {*} d
     * @param {*} u
     * @return {*}
     */
    GetSelectSuccess: (d, u) => {
      return {
        CUST_CODE: d.values['val'],
      };
    },
    InitCrudFormSchema: (type: string, ...args) => {
      return [
        {
          field: 'INS_CODE',
          label: '点检项目编码',
          component: 'Input',
          isexist: 'Y',
          show: true,
          required: true,
          colProps: {
            span: 24,
          },
        },
        {
          field: 'INS_NAME',
          label: '点检项目名称',
          component: 'Input',
          isexist: 'N',
          show: true,
          required: true,
          colProps: {
            span: 24,
          },
        },
        {
          field: 'IS_NECESSARY',
          label: '是否必检(Y/N)',
          component: 'Select',
          isexist: 'N',
          componentProps: {
            options: [
              {
                label: '是',
                value: 'Y',
                key: '0',
              },
              {
                label: '否',
                value: 'N',
                key: '0',
              },
            ],
          },
          show: true,
          required: true,
          colProps: {
            span: 24,
          },
        },
        {
          field: 'IS_JUDGE',
          label: '是否判定结果(Y/N)',
          component: 'Select',
          isexist: 'N',
          componentProps: {
            options: [
              {
                label: '是',
                value: 'Y',
                key: '0',
              },
              {
                label: '否',
                value: 'N',
                key: '0',
              },
            ],
          },
          show: true,
          required: false,
          colProps: {
            span: 24,
          },
        },
        {
          field: 'INS_MODE',
          label: '检验方式',
          component: 'ApiSelect',
          isexist: 'N',
          componentProps: {
            api: 'GetEnum',
            params: {},
            resultField: 'Data',
            labelField: 'Desc',
            valueField: 'Value',
          },
          show: true,
          required: false,
          colProps: {
            span: 24,
          },
        },
        {
          field: 'QNTV_UNIT',
          label: '测试值单位',
          component: 'Input',
          isexist: 'N',
          ifShow: ({ values }) => isQuantitative(values.INS_MODE),
          required: false,
          colProps: {
            span: 24,
          },
        },
        {
          field: 'QNTV_TIMES',
          label: '测试次数(0-20)',
          component: 'Input',
          isexist: 'N',
          ifShow: ({ values }) => isQuantitative(values.INS_MODE),
          required: false,
          colProps: {
            span: 24,
          },
        },
        {
          field: 'QNTV_DEVIATION',
          label: '偏差值',
          component: 'Input',
          isexist: 'N',
          ifShow: ({ values }) => isQuantitative(values.INS_MODE),
          required: false,
          colProps: {
            span: 24,
          },
        },
        {
          field: 'QNTV_UPPER',
          label: '测试范围上限',
          component: 'Input',
          isexist: 'N',
          ifShow: ({ values }) => isQuantitative(values.INS_MODE),
          required: false,
          colProps: {
            span: 24,
          },
        },
        {
          field: 'QNTV_LOWER',
          label: '测试范围下限',
          component: 'Input',
          isexist: 'N',
          ifShow: ({ values }) => isQuantitative(values.INS_MODE),
          required: false,
          colProps: {
            span: 24,
          },
        },
        {
          field: 'QLTV_LIST',
          label: '测试项列表',
          component: 'Input',
          isexist: 'N',
          ifShow: ({ values }) => isQualitative(values.INS_MODE),
          required: false,
          colProps: {
            span: 24,
          },
          renderComponentContent: (_, { disabled }) => {
            return {
              suffix: () => '用“|”分隔，最多20项',
            };
          },
        },
        {
          field: 'REMARK',
          label: '备注',
          component: 'Input',
          isexist: 'N',
          show: true,
          required: false,
          colProps: {
            span: 24,
          },
        },
        {
          field: 'ID',
          label: '唯一ID',
          component: '',
          show: false,
          required: false,
          colProps: {
            span: 24,
          },
        },
      ];
    },
    GetUseForm: () => {
      return {};
    },
  };

  return [methods, ActionColumn];
}

export default _default;
